@@ -11,10 +11,10 @@ from transformers import (
 
 class K2TPipeline:
     def __init__(
-            self,
-            model: PreTrainedModel,
-            tokenizer: PreTrainedTokenizer,
-            use_cuda: bool
+        self,
+        model: PreTrainedModel,
+        tokenizer: PreTrainedTokenizer,
+        use_cuda: bool
     ):
         self.model = model
         self.tokenizer = tokenizer
@@ -45,25 +45,25 @@ class K2TPipeline:
             outputs = self.model.generate(input_ids.to(self.device), **kwargs)
             result += self.tokenizer.decode(outputs[0])
 
-        result = re.sub('<pad>|</s>', "", result)
+        result = re.sub("<pad>|</s>", "", result)
         return result
 
     def _prepare_inputs_for_k2t(self, keywords):
         text = str(keywords)
-        text = text.replace(',', '|')
+        text = text.replace(",", "|")
         text = text.replace("'", "")
-        text = text.replace('[', '')
-        text = text.replace(']', '')
+        text = text.replace("[", "")
+        text = text.replace("]", "")
         texts = text.split(".")
         return texts
 
     def _tokenize(
-            self,
-            inputs,
-            padding=True,
-            truncation=True,
-            add_special_tokens=True,
-            max_length=1024
+        self,
+        inputs,
+        padding=True,
+        truncation=True,
+        add_special_tokens=True,
+        max_length=1024,
     ):
         inputs = self.tokenizer.encode(
             inputs,
@@ -72,7 +72,7 @@ class K2TPipeline:
             truncation=truncation,
             padding="max_length" if padding else False,
             pad_to_max_length=padding,
-            return_tensors="pt"
+            return_tensors="pt",
         )
         return inputs
 
@@ -82,19 +82,23 @@ SUPPORTED_TASKS = {
         "impl": K2TPipeline,
         "default": {
             "model": "gagan3012/k2t",
-        }
+        },
     }
 }
 
 
 def pipeline(
-        task: str,
-        model: Optional = None,
-        tokenizer: Optional[Union[str, PreTrainedTokenizer]] = None,
-        use_cuda: Optional[bool] = True,
+    task: str,
+    model: Optional = None,
+    tokenizer: Optional[Union[str, PreTrainedTokenizer]] = None,
+    use_cuda: Optional[bool] = True,
 ):
     if task not in SUPPORTED_TASKS:
-        raise KeyError("Unknown task {}, available tasks are {}".format(task, list(SUPPORTED_TASKS.keys())))
+        raise KeyError(
+            "Unknown task {}, available tasks are {}".format(
+                task, list(SUPPORTED_TASKS.keys())
+            )
+        )
 
     targeted_task = SUPPORTED_TASKS[task]
     task_class = targeted_task["impl"]
@@ -108,7 +112,8 @@ def pipeline(
         else:
             # Impossible to guest what is the right tokenizer here
             raise Exception(
-                "Please provided a PretrainedTokenizer class or a path/identifier to a pretrained tokenizer."
+                "Please provided a PretrainedTokenizer "
+                "class or a path/identifier to a pretrained tokenizer."
             )
     if isinstance(tokenizer, (str, tuple)):
         tokenizer = AutoTokenizer.from_pretrained(tokenizer)
@@ -119,4 +124,3 @@ def pipeline(
 
     if task == "k2t":
         return task_class(model=model, tokenizer=tokenizer, use_cuda=use_cuda)
-
